@@ -11,7 +11,7 @@
 
 glm::glm(const reg_Method *mm)
    : mmRef(mm), Yref(NULL), Xref(NULL), Oref(NULL), 
-     Beta(NULL), varBeta(NULL), Mu(NULL), Eta(NULL), Res(NULL), 
+     Beta(NULL), varBeta(NULL), Mu(NULL), Eta(NULL), Res(NULL), PearRes(NULL), 
      Var(NULL), wHalf(NULL), sqrt1_Hii(NULL), PitRes(NULL), 
      theta(NULL), ll(NULL), dev(NULL), aic(NULL), iterconv(NULL) 
 { 
@@ -71,6 +71,8 @@ void glm::releaseGlm(void)
         gsl_matrix_free(Eta);
     if (Res!=NULL)
         gsl_matrix_free(Res);
+    if (PearRes!=NULL)
+        gsl_matrix_free(PearRes);
     if (Var!=NULL)
         gsl_matrix_free(Var);
     if (wHalf!=NULL)
@@ -120,6 +122,7 @@ void glm::initialGlm(gsl_matrix *Y, gsl_matrix *X, gsl_matrix *O, gsl_matrix *B)
     Mu = gsl_matrix_alloc(nRows, nVars);
     Eta = gsl_matrix_alloc(nRows, nVars);
     Res = gsl_matrix_alloc(nRows, nVars);
+    PearRes = gsl_matrix_alloc(nRows, nVars);
     Var = gsl_matrix_alloc(nRows, nVars);
     wHalf = gsl_matrix_alloc(nRows, nVars);
     sqrt1_Hii = gsl_matrix_alloc(nRows, nVars);
@@ -148,11 +151,11 @@ void glm::initialGlm(gsl_matrix *Y, gsl_matrix *X, gsl_matrix *O, gsl_matrix *B)
     double eij;
     if (mmRef->model==BIN) {
         LinAdjust=0.5;
-    ScaleAdjust=0.5;
+        ScaleAdjust=0.5;
     }
     else {
         LinAdjust=0.1;
-    ScaleAdjust=1;
+        ScaleAdjust=1;
     }
     if (B!=NULL) {
        gsl_matrix_memcpy(Beta, B);
@@ -200,6 +203,8 @@ void glm::initialGlm(gsl_matrix *Y, gsl_matrix *X, gsl_matrix *O, gsl_matrix *B)
     }
 
    rdf = nRows - nParams;
+
+//   displaymatrix(Oref, "Oref");
 }
 
 
@@ -217,6 +222,7 @@ int glm::copyGlm(glm *src)
     gsl_matrix_memcpy(wHalf, src->wHalf);
     gsl_matrix_memcpy(sqrt1_Hii, src->sqrt1_Hii);
     gsl_matrix_memcpy(PitRes, src->PitRes);
+    gsl_matrix_memcpy(PearRes, src->PearRes);
     
     for (unsigned int i=0; i<nVars; i++) {
         theta[i] = src->theta[i];   
@@ -237,7 +243,7 @@ int PoissonGlm::EstIRLS(gsl_matrix *Y, gsl_matrix *X, gsl_matrix *O, gsl_matrix
     gsl_rng *rnd=gsl_rng_alloc(gsl_rng_mt19937);
     unsigned int i, j;   
     int status;
-    double yij, mij, vij, wij, tol, hii, uij, wei;
+    double yij, mij, eij, vij, wij, tol, hii, uij, wei;
     gsl_vector_view Xwi, Xi, vj, hj, dj;
 
     gsl_matrix *WX = gsl_matrix_alloc(nRows, nParams);   
@@ -253,6 +259,7 @@ int PoissonGlm::EstIRLS(gsl_matrix *Y, gsl_matrix *X, gsl_matrix *O, gsl_matrix
        gsl_matrix_memcpy (WX, X);
        for (i=0; i<nRows; i++) {
             mij = gsl_matrix_get(Mu, i, j);
+            eij = gsl_matrix_get(Eta, i, j);
             // get variance
             vij = varfunc( mij, theta[j] );
             gsl_matrix_set(Var, i, j, vij); 
@@ -261,7 +268,8 @@ int PoissonGlm::EstIRLS(gsl_matrix *Y, gsl_matrix *X, gsl_matrix *O, gsl_matrix
             gsl_matrix_set(wHalf, i, j, wij);             
             // get (Pearson) residuals
             yij = gsl_matrix_get(Y, i, j);
-            gsl_matrix_set(Res, i, j, (yij-mij)/sqrt(vij));        
+            gsl_matrix_set(PearRes, i, j, (yij-mij)/sqrt(vij));        
+            gsl_matrix_set(Res, i, j, (yij-mij)/muEta(eij));        
             // get PIT residuals for discrete data
             wei = gsl_rng_uniform_pos (rnd); // wei ~ U(0, 1)
             uij = wei*cdf(yij, mij, theta[j]);
@@ -305,8 +313,8 @@ int PoissonGlm::EstIRLS(gsl_matrix *Y, gsl_matrix *X, gsl_matrix *O, gsl_matrix
        } 
    } 
    // standardize perason residuals by rp/sqrt(1-hii) 
-   gsl_matrix_div_elements (Res, sqrt1_Hii);
-   subtractMean(Res);  // have mean subtracted
+   gsl_matrix_div_elements (PearRes, sqrt1_Hii);
+   subtractMean(PearRes);  // have mean subtracted
 
    gsl_matrix_free(XwX);
    gsl_matrix_free(WX);
@@ -322,9 +330,10 @@ int PoissonGlm::betaEst( unsigned int id, unsigned int iter, double *tol, double
    gsl_set_error_handler_off();
    int status, isValid;
   // unsigned int j, ngoodobs;
-   unsigned int i, step, step1; 
+   unsigned int i, j, ngoodobs, step, step1; 
+   unsigned int *good = new unsigned int [nRows];
    double wij, zij, eij, mij, yij; //, bij;   
-   double det, dev_old, dev_grad=1.0;
+   double dev_old, dev_grad=1.0;
    gsl_vector_view Xwi;
    gsl_matrix *WX, *XwX;
    gsl_vector *z, *Xwz;
@@ -340,14 +349,26 @@ int PoissonGlm::betaEst( unsigned int id, unsigned int iter, double *tol, double
    *tol = 1.0;
    gsl_vector_memcpy (coef_old, &bj.vector);
    while ( step<iter ) {
+       ngoodobs = 0;
+       for (i=0; i<nRows; i++) {
+            good[i]=TRUE;
+	    eij = gsl_matrix_get(Eta, i, id);
+	    mij = gsl_matrix_get(Mu, i, id);
+	    if ((mij<mintol)|(mij>maxtol)) good[i]=FALSE;
+//	    if (rcpLinkDash(mij)<eps) good[i]=FALSE;
+	    if (good[i]==TRUE) ngoodobs++;
+       }									             z = gsl_vector_alloc(ngoodobs);
+       WX = gsl_matrix_alloc(ngoodobs, nParams);
+       j=0;  // index for z and WX
        for (i=0; i<nRows; i++) { // (y-m)/g'
+       if (good[i]==TRUE) {
            yij = gsl_matrix_get(Yref, i, id);
            eij = gsl_matrix_get(Eta, i, id);
            mij = gsl_matrix_get(Mu, i, id);
         //   if (mij<mintol) mij=mintol;
         //   if (mij>maxtol) mij=maxtol;
-           zij = eij + (yij-mij)/rcpLinkDash(mij);
-           if (Oref!=NULL) 
+           zij = eij + (yij-mij)*LinkDash(mij);
+           if (Oref!=NULL)  
               zij = zij - gsl_matrix_get(Oref, i, id);
            // wt=sqrt(weifunc);
            wij = sqrt(weifunc(mij, th));
@@ -358,7 +379,7 @@ int PoissonGlm::betaEst( unsigned int id, unsigned int iter, double *tol, double
            gsl_matrix_set_row (WX, i, &Xwi.vector);
            Xwi = gsl_matrix_row (WX, i);
            gsl_vector_scale(&Xwi.vector, wij); 
-       }
+       }  }
        // in glm2, solve WXb=Wz, David suggested not good 
        // So back to solving X'WXb=X'Wz
        gsl_matrix_set_identity (XwX);
@@ -437,6 +458,7 @@ int PoissonGlm::betaEst( unsigned int id, unsigned int iter, double *tol, double
        if (*tol<eps) break;
    } 
 
+   delete[] good;
    gsl_vector_free(z);
    gsl_matrix_free(WX); 
    gsl_matrix_free(XwX); 
@@ -501,8 +523,8 @@ int NBinGlm::nbinfit(gsl_matrix *Y, gsl_matrix *X, gsl_matrix *O, gsl_matrix *B)
 
     gsl_rng *rnd=gsl_rng_alloc(gsl_rng_mt19937);
     unsigned int i, j; //, isConv;
-    double yij, mij, vij, hii, uij, wij, wei;
-    double lm, lm0, d1, th, tol, dev_th_b_old;
+    double yij, eij, mij, vij, hii, uij, wij, wei;
+    double th=0, d1, tol, dev_th_b_old;
     int status;
  //   gsl_vector_view b0j, m0j, e0j, v0j;
     gsl_matrix *WX = gsl_matrix_alloc(nRows, nParams);   
@@ -535,7 +557,7 @@ int NBinGlm::nbinfit(gsl_matrix *Y, gsl_matrix *X, gsl_matrix *O, gsl_matrix *B)
                tol=ABS((dev[j]-dev_th_b_old)/(ABS(dev[j])+0.1));
                if (tol<eps) break;
         }  } 
-       else if (mmRef->estiMethod==PHI) {
+       else { // (mmRef->estiMethod==PHI) {
            th = getfAfAdash(0, j, maxiter);
 /*           lm=0;
            for (i=0; i<nRows; i++) {
@@ -570,11 +592,13 @@ int NBinGlm::nbinfit(gsl_matrix *Y, gsl_matrix *X, gsl_matrix *O, gsl_matrix *B)
        for (i=0; i<nRows; i++) {
            yij = gsl_matrix_get(Y, i, j);
            mij = gsl_matrix_get(Mu, i, j);
+           eij = gsl_matrix_get(Eta, i, j);
            vij = varfunc( mij, th);
            gsl_matrix_set(Var, i, j, vij); 
            wij = sqrt(weifunc(mij, th));
            gsl_matrix_set(wHalf, i, j, wij); 
-           gsl_matrix_set(Res, i, j, (yij-mij)/sqrt(vij));        
+           gsl_matrix_set(PearRes, i, j, (yij-mij)/sqrt(vij));        
+           gsl_matrix_set(Res, i, j, (yij-mij)/muEta(eij));        
            ll[j] = ll[j] + llfunc( yij, mij, th);
            // get PIT residuals for discrete data
            wei = gsl_rng_uniform_pos (rnd); // wei ~ U(0, 1)
@@ -616,8 +640,8 @@ int NBinGlm::nbinfit(gsl_matrix *Y, gsl_matrix *X, gsl_matrix *O, gsl_matrix *B)
            gsl_vector_set(&hj.vector, i, GSL_MAX(eps,sqrt(1-wij*wij*hii)));
        }
    } // end nVar for j loop
-   gsl_matrix_div_elements (Res, sqrt1_Hii);
-   subtractMean(Res);
+   gsl_matrix_div_elements (PearRes, sqrt1_Hii);
+   subtractMean(PearRes);
 
    gsl_matrix_free(XwX);
    gsl_matrix_free(WX);
